@@ -50,7 +50,7 @@ class FirestoreChangeRec(object):
         
     def processUpdate(self,processValue):
         try:
-            self._processUpdate(processValue)
+            return self._processUpdate(processValue)
         except Exception as e:
             print(f"Error processing the {processValue} in the event.")
             print(self.event[processValue])
